@@ -53,5 +53,5 @@ class SimpleQueue:
         return len(self._dict)
 
     def clear(self):
-        self._queue.clear()
+        self._queue.queue.clear()
         self._dict.clear()
\ No newline at end of file
