@@ -28,7 +28,7 @@ class SimpleClient():
         return self._topic().get_batch(self._topic_name, max_num)
 
     def commit_batch(self, qid_list):
-        results = [self._topic().ack(self._topic_name, qid) for qid in qid_list]
+        results = [self.simple_topic().ack(self._topic_name, qid) for qid in qid_list]
         return results
 
     def rebind(self):
